@@ -69,8 +69,8 @@ void
 constraint_update_info_cb 	(GtkWidget 	*widget, 
 				 gpointer 	data);	
 void    
-constraint_menu_toggled_cb	(GtkWidget 	*widget, 
-				 gpointer 	data);
+constraint_menu_item_activate_cb(GtkWidget 	*widget,
+                                 gpointer 	data);
 void    
 constraint_entry_changed_cb 	(GtkWidget 	*widget, 
 				 gpointer 	data);
@@ -83,6 +83,9 @@ open_file_cb 			(GtkWidget 	*widget,
 void	
 open_folder_cb 			(GtkWidget 	*widget, 
 				 gpointer 	data);
+void	
+move_to_trash_cb		(GtkWidget 	*widget, 
+				 gpointer 	data);				 
 void  
 drag_begin_file_cb  		(GtkWidget          *widget,
 	      			 GdkDragContext     *context,
