@@ -72,8 +72,8 @@ struct _FindOptionTemplate {
 static FindOptionTemplate templates[] = {
 	{ SEARCH_CONSTRAINT_TEXT, "-exec grep -c '%s' {} \\;", N_("Contains the _text"), FALSE },
 	{ SEARCH_CONSTRAINT_SEPARATOR, NULL, NULL, TRUE },
-	{ SEARCH_CONSTRAINT_TIME, "-mtime -%d", N_("_Date modified less than (days)"), FALSE },
-	{ SEARCH_CONSTRAINT_TIME, "-mtime +%d", N_("Date modified more than (da_ys)"), FALSE },
+	{ SEARCH_CONSTRAINT_TIME_LESS, "-mtime -%d", N_("_Date modified less than (days)"), FALSE },
+	{ SEARCH_CONSTRAINT_TIME_MORE, "\\( -mtime +%d -o -mtime %d \\)", N_("Date modified more than (da_ys)"), FALSE },
 	{ SEARCH_CONSTRAINT_SEPARATOR, NULL, NULL, TRUE },
 	{ SEARCH_CONSTRAINT_NUMBER, "-size +%uc", N_("S_ize at least (kilobytes)"), FALSE }, 
 	{ SEARCH_CONSTRAINT_NUMBER, "-size -%uc", N_("Si_ze at most (kilobytes)"), FALSE },
@@ -299,9 +299,14 @@ build_search_command (void)
 	look_in_folder_locale = g_locale_from_utf8 (look_in_folder_utf8, -1, NULL, NULL, NULL);
 	gnome_entry_prepend_history (GNOME_ENTRY(gnome_file_entry_gnome_entry (GNOME_FILE_ENTRY(interface.look_in_folder_entry))), 
 				     TRUE, look_in_folder_utf8);
+	g_free (look_in_folder_utf8);
 	
 	if (!file_extension_is (look_in_folder_locale, G_DIR_SEPARATOR_S)) {
+		gchar *tmp;
+		
+		tmp = look_in_folder_locale;
 		look_in_folder_locale = g_strconcat (look_in_folder_locale, G_DIR_SEPARATOR_S, NULL);
+		g_free (tmp);
 	}
 	search_command.look_in_folder = g_strdup(look_in_folder_locale);
 	
@@ -320,7 +325,8 @@ build_search_command (void)
 		
 		if ((disable_quick_search != TRUE) && (locate != NULL) 
 		    && (is_path_in_home_folder (look_in_folder_locale) != TRUE) 
-		    && (is_path_in_mount_folder (look_in_folder_locale) != TRUE)) {	
+		    && (is_path_in_mount_folder (look_in_folder_locale) != TRUE)
+		    && (is_path_in_tmp_folder (look_in_folder_locale) != TRUE)) {	
 			g_string_append_printf (command, "%s %s '%s*%s'", 
 						locate,
 						locate_command_default_options,
@@ -403,11 +409,18 @@ build_search_command (void)
 					  		(constraint->data.number * 1024));
 				g_string_append_c (command, ' ');
 				break;
-			case SEARCH_CONSTRAINT_TIME:
+			case SEARCH_CONSTRAINT_TIME_LESS:
 				g_string_append_printf (command,
 					 		templates[constraint->constraint_id].option,
 					  		constraint->data.time);
 				g_string_append_c (command, ' ');
+				break;	
+			case SEARCH_CONSTRAINT_TIME_MORE:
+				g_string_append_printf (command,
+					 		templates[constraint->constraint_id].option,
+					  		constraint->data.time,
+					  		constraint->data.time);
+				g_string_append_c (command, ' ');
 				break;
 			default:
 		        	break;
@@ -531,14 +544,63 @@ add_no_files_found_message (GtkListStore 	*store,
 		    	    -1);
 }
 
+void
+update_search_counts (void)
+{
+	gchar  *title_bar_string = NULL;
+	gchar  *message_string = NULL;
+	gchar  *stopped_string = g_strdup ("");
+	gchar  *tmp;
+	gint   total_files;
+
+	if (search_command.aborted == TRUE) {
+		stopped_string = g_strdup (_("(stopped)"));
+	}
+	
+	total_files = gtk_tree_model_iter_n_children (GTK_TREE_MODEL(interface.model), NULL);
+
+	if (total_files == 0) {
+		title_bar_string = g_strdup (_("No Files Found"));
+		message_string = g_strdup (_("No files found"));
+		add_no_files_found_message (interface.model, &interface.iter);
+	}
+	else if (total_files == 1) {
+		title_bar_string = g_strdup (_("One File Found"));
+		message_string = g_strdup (_("One file found"));
+	}
+	else {
+		title_bar_string = g_strdup_printf (_("%d Files Found"), total_files);
+		message_string = g_strdup_printf (_("%d files found"), total_files);
+	}
+		
+	if (strlen (stopped_string) > 0) {
+		tmp = message_string;
+		message_string = g_strconcat (message_string, " ", stopped_string, NULL);
+		g_free (tmp);
+		
+		tmp = title_bar_string;
+		title_bar_string = g_strconcat (title_bar_string, " ", stopped_string, NULL);
+		g_free (tmp);
+	}
+		
+	tmp = title_bar_string;
+	title_bar_string = g_strconcat (title_bar_string, " - ", _("Search for Files"), NULL);
+	gtk_window_set_title (GTK_WINDOW (interface.main_window), title_bar_string);
+	g_free (tmp);
+	
+	gtk_label_set_text (GTK_LABEL (interface.results_label), message_string);
+	
+	g_free (title_bar_string);
+	g_free (message_string);
+	g_free (stopped_string);
+}
+
 static GtkWidget *
 make_list_of_templates (void)
 {
 	gboolean ACTIVATE_MENU_OPTION = TRUE;
 	GtkWidget *menu;
 	GtkWidget *menuitem;
-	GtkWidget *separator;
-	GSList    *group = NULL;
 	gint i;
 
 	menu = gtk_menu_new ();
@@ -546,30 +608,26 @@ make_list_of_templates (void)
 	for(i=0; templates[i].type != SEARCH_CONSTRAINT_END; i++) {
 		
 		if (templates[i].type == SEARCH_CONSTRAINT_SEPARATOR) {
-			menuitem = gtk_menu_item_new ();
-			separator = gtk_hseparator_new ();
-			gtk_container_add (GTK_CONTAINER (menuitem), separator);	
+			menuitem = gtk_separator_menu_item_new ();	
 			gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
-			gtk_widget_show (separator);
 			gtk_widget_show (menuitem);
 		} 
 		else {
 			gchar *text = remove_mnemonic_character (_(templates[i].desc));
-			menuitem = gtk_radio_menu_item_new_with_label (group, text);
-			g_signal_connect (G_OBJECT(menuitem), "toggled",
-					  G_CALLBACK(constraint_menu_toggled_cb),
+			menuitem = gtk_menu_item_new_with_label (text);
+			g_signal_connect (G_OBJECT(menuitem), "activate",
+					  G_CALLBACK(constraint_menu_item_activate_cb),
 		        		  (gpointer)(long)i);
-			group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (menuitem));
 			gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
 			gtk_widget_show (menuitem);
 			g_free (text);
 		}
 		
-		if (templates[i].is_selected == TRUE) {
+		if (templates[i].is_selected) {
 			gtk_widget_set_sensitive (menuitem, FALSE);
 		}
 		else {
-			if (ACTIVATE_MENU_OPTION == TRUE) {
+			if (ACTIVATE_MENU_OPTION) {
 				ACTIVATE_MENU_OPTION = FALSE;
 				g_signal_emit_by_name (G_OBJECT(menuitem), "activate", NULL);
 			}
@@ -590,7 +648,8 @@ set_constraint_info_defaults (SearchConstraint *opt)
 	case SEARCH_CONSTRAINT_NUMBER:
 		opt->data.number = 0;
 		break;
-	case SEARCH_CONSTRAINT_TIME:
+	case SEARCH_CONSTRAINT_TIME_LESS:
+	case SEARCH_CONSTRAINT_TIME_MORE:
 		opt->data.time = 0;
 		break;
 	default:
@@ -609,7 +668,8 @@ update_constraint_info (SearchConstraint 	*constraint,
 	case SEARCH_CONSTRAINT_NUMBER:
 		sscanf (info, "%d", &constraint->data.number);
 		break;
-	case SEARCH_CONSTRAINT_TIME:
+	case SEARCH_CONSTRAINT_TIME_LESS:
+	case SEARCH_CONSTRAINT_TIME_MORE:
 		sscanf (info, "%d", &constraint->data.time);
 		break;
 	default:
@@ -647,59 +707,59 @@ set_constraint_gconf_boolean (gint constraint_id, gboolean flag)
 	switch (constraint_id) {
 	
 		case SEARCH_CONSTRAINT_CONTAINS_THE_TEXT:
-			gsearchtool_gconf_set_boolean ("/apps/gnome-search-tool/contains_the_text",
+			gsearchtool_gconf_set_boolean ("/apps/gnome-search-tool/select/contains_the_text",
 	   		       	       	       	       flag);
 			break;
 		case SEARCH_CONSTRAINT_DATE_MODIFIED_BEFORE:
-			gsearchtool_gconf_set_boolean ("/apps/gnome-search-tool/date_modified_less_than",
+			gsearchtool_gconf_set_boolean ("/apps/gnome-search-tool/select/date_modified_less_than",
 	   		       	       	       	       flag);
 			break;
 		case SEARCH_CONSTRAINT_DATE_MODIFIED_AFTER:
-			gsearchtool_gconf_set_boolean ("/apps/gnome-search-tool/date_modified_more_than",
+			gsearchtool_gconf_set_boolean ("/apps/gnome-search-tool/select/date_modified_more_than",
 	   		       	       	       	       flag);
 			break;
 		case SEARCH_CONSTRAINT_SIZE_IS_MORE_THAN:
-			gsearchtool_gconf_set_boolean ("/apps/gnome-search-tool/size_at_least",
+			gsearchtool_gconf_set_boolean ("/apps/gnome-search-tool/select/size_at_least",
 	   		       	       		       flag);
 			break;
 		case SEARCH_CONSTRAINT_SIZE_IS_LESS_THAN:
-			gsearchtool_gconf_set_boolean ("/apps/gnome-search-tool/size_at_most",
+			gsearchtool_gconf_set_boolean ("/apps/gnome-search-tool/select/size_at_most",
 	   		       	       	  	       flag);
 			break;
 		case SEARCH_CONSTRAINT_FILE_IS_EMPTY:
-			gsearchtool_gconf_set_boolean ("/apps/gnome-search-tool/file_is_empty",
+			gsearchtool_gconf_set_boolean ("/apps/gnome-search-tool/select/file_is_empty",
 	   		       	       	               flag);
 			break;
 		case SEARCH_CONSTRAINT_OWNED_BY_USER:
-			gsearchtool_gconf_set_boolean ("/apps/gnome-search-tool/owned_by_user",
+			gsearchtool_gconf_set_boolean ("/apps/gnome-search-tool/select/owned_by_user",
 	   		       	       	               flag);
 			break;
 		case SEARCH_CONSTRAINT_OWNED_BY_GROUP:
-			gsearchtool_gconf_set_boolean ("/apps/gnome-search-tool/owned_by_group",
+			gsearchtool_gconf_set_boolean ("/apps/gnome-search-tool/select/owned_by_group",
 	   		       	       	               flag);
 			break;
 		case SEARCH_CONSTRAINT_OWNER_IS_UNRECOGNIZED:
-			gsearchtool_gconf_set_boolean ("/apps/gnome-search-tool/owner_is_unrecognized",
+			gsearchtool_gconf_set_boolean ("/apps/gnome-search-tool/select/owner_is_unrecognized",
 	   		       	       	               flag);
 			break;
 		case SEARCH_CONSTRAINT_FILE_IS_NOT_NAMED:
-			gsearchtool_gconf_set_boolean ("/apps/gnome-search-tool/name_does_not_contain",
+			gsearchtool_gconf_set_boolean ("/apps/gnome-search-tool/select/name_does_not_contain",
 	   		       	       	               flag);
 			break;
 		case SEARCH_CONSTRAINT_FILE_MATCHES_REGULAR_EXPRESSION:
-			gsearchtool_gconf_set_boolean ("/apps/gnome-search-tool/name_matches_regular_expression",
+			gsearchtool_gconf_set_boolean ("/apps/gnome-search-tool/select/name_matches_regular_expression",
 	   		       	       	               flag);
 			break;
 		case SEARCH_CONSTRAINT_SHOW_HIDDEN_FILES_AND_FOLDERS:
-			gsearchtool_gconf_set_boolean ("/apps/gnome-search-tool/show_hidden_files_and_folders",
+			gsearchtool_gconf_set_boolean ("/apps/gnome-search-tool/select/show_hidden_files_and_folders",
 	   		       	       	               flag);
 			break;
 		case SEARCH_CONSTRAINT_FOLLOW_SYMBOLIC_LINKS:
-			gsearchtool_gconf_set_boolean ("/apps/gnome-search-tool/follow_symbolic_links",
+			gsearchtool_gconf_set_boolean ("/apps/gnome-search-tool/select/follow_symbolic_links",
 	   		       	       	               flag);
 			break;
 		case SEARCH_CONSTRAINT_SEARCH_OTHER_FILESYSTEMS:
-			gsearchtool_gconf_set_boolean ("/apps/gnome-search-tool/include_other_filesystems",
+			gsearchtool_gconf_set_boolean ("/apps/gnome-search-tool/select/include_other_filesystems",
 	   		       	       	               flag);
 			break;
 		
@@ -791,9 +851,10 @@ get_desktop_item_name (void)
 	look_in_folder_locale = g_locale_from_utf8 (look_in_folder_utf8 != NULL ? look_in_folder_utf8 : "", 
 	                                            -1, NULL, NULL, NULL);
 	g_string_append (gs, g_strdup_printf ("&path=%s", look_in_folder_locale));
-	g_free (look_in_folder_locale); 
+	g_free (look_in_folder_locale);
+	g_free (look_in_folder_utf8); 
 
-	if (GTK_WIDGET_VISIBLE(interface.additional_constraints) == TRUE) {
+	if (GTK_WIDGET_VISIBLE(interface.additional_constraints)) {
 		for (list = interface.selected_constraints; list != NULL; list = g_list_next (list)) {
 			SearchConstraint *constraint = list->data;
 			gchar *locale = NULL;
@@ -862,7 +923,7 @@ setup_animation_image (void)
 	gint	   width  = 0;
 	gint	   height = 0;
 	GError     *error = NULL;
-			
+
 	interface.current_animation_frame = DEFAULT_ANIMATION_FRAME - 1;
 
 	interface.pixbuf = gdk_pixbuf_new_from_file (GNOME_ICONDIR"/gnome-search-tool/gnome-search-tool-animation.png",
@@ -879,7 +940,6 @@ setup_animation_image (void)
 	height = gdk_pixbuf_get_height (interface.pixbuf); 
 
 	gtk_drawing_area_size (GTK_DRAWING_AREA (interface.drawing_area), width / TOTAL_ANIMATION_FRAMES, height);
-	interface.pixmap = gdk_pixmap_new (interface.drawing_area->window, width, height, -1);
 	gtk_widget_queue_draw (interface.drawing_area); 
 
 	return TRUE;
@@ -893,7 +953,7 @@ animation_expose_event_cb (GtkWidget       *widget,
 	gint width  = 0;
 	gint height = 0;
 
-	if (GDK_IS_DRAWABLE (interface.pixmap) == FALSE) {
+	if (interface.pixbuf == NULL) {
 		return FALSE;
 	}
 
@@ -903,13 +963,14 @@ animation_expose_event_cb (GtkWidget       *widget,
 
 	gdk_gc_set_clip_rectangle (widget->style->fg_gc[widget->state], &event->area); 
 
-	gdk_drawable_get_size (interface.pixmap, &width, &height);
+	width  = gdk_pixbuf_get_width (interface.pixbuf); 
+	height = gdk_pixbuf_get_height (interface.pixbuf); 
 
 	gdk_pixbuf_render_to_drawable_alpha (interface.pixbuf,
 	                                     GDK_DRAWABLE (widget->window),
 	                                     (width * interface.current_animation_frame) / TOTAL_ANIMATION_FRAMES, 0, 
 	                                     0, 0,
-	                                     width, height,
+	                                     width / TOTAL_ANIMATION_FRAMES, height,
 	                                     GDK_PIXBUF_ALPHA_FULL, 255,
 	                                     GDK_RGB_DITHER_MAX,
 	                                     0, 0);
@@ -946,7 +1007,7 @@ update_animation_timeout_cb (gpointer data)
 {
 	static gboolean in_forward_progress = TRUE;
 	
-	if (in_forward_progress == TRUE) {
+	if (in_forward_progress) {
 		interface.current_animation_frame++;
 		if (interface.current_animation_frame >= (TOTAL_ANIMATION_FRAMES - 1)) {
 			in_forward_progress = !in_forward_progress;
@@ -1026,7 +1087,7 @@ handle_popt_args (void)
 		add_constraint (SEARCH_CONSTRAINT_SIZE_IS_LESS_THAN,
 				PoptArgument.sizeless, TRUE);
 	}
-	if (PoptArgument.empty == TRUE) {
+	if (PoptArgument.empty) {
 		popt_args_found = TRUE;
 		add_constraint (SEARCH_CONSTRAINT_FILE_IS_EMPTY, NULL, TRUE);
 	}
@@ -1040,7 +1101,7 @@ handle_popt_args (void)
 		add_constraint (SEARCH_CONSTRAINT_OWNED_BY_GROUP, 
 				PoptArgument.group, TRUE);
 	}
-	if (PoptArgument.nouser == TRUE) {
+	if (PoptArgument.nouser) {
 		popt_args_found = TRUE;
 		add_constraint (SEARCH_CONSTRAINT_OWNER_IS_UNRECOGNIZED, NULL, TRUE); 
 	}
@@ -1054,15 +1115,15 @@ handle_popt_args (void)
 		add_constraint (SEARCH_CONSTRAINT_FILE_MATCHES_REGULAR_EXPRESSION, 
 				PoptArgument.regex, TRUE);
 	}
-	if (PoptArgument.hidden == TRUE) {
+	if (PoptArgument.hidden) {
 		popt_args_found = TRUE;
 		add_constraint (SEARCH_CONSTRAINT_SHOW_HIDDEN_FILES_AND_FOLDERS, NULL, TRUE);
 	}
-	if (PoptArgument.follow == TRUE) {
+	if (PoptArgument.follow) {
 		popt_args_found = TRUE;
 		add_constraint (SEARCH_CONSTRAINT_FOLLOW_SYMBOLIC_LINKS, NULL, TRUE); 
 	}
-	if (PoptArgument.allmounts == TRUE) {
+	if (PoptArgument.allmounts) {
 		popt_args_found = TRUE;
 		add_constraint (SEARCH_CONSTRAINT_SEARCH_OTHER_FILESYSTEMS, NULL, TRUE);
 	}
@@ -1089,7 +1150,7 @@ handle_popt_args (void)
 			sort_by = COLUMN_NAME;
 		}
 			
-		if (PoptArgument.descending == TRUE) {
+		if (PoptArgument.descending) {
 			gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE (interface.model), sort_by,
 							      GTK_SORT_DESCENDING);
 		} 
@@ -1098,7 +1159,7 @@ handle_popt_args (void)
 							      GTK_SORT_ASCENDING);
 		}
 	}
-	if (PoptArgument.start == TRUE) {
+	if (PoptArgument.start) {
 		popt_args_found = TRUE;
 		click_find_cb (interface.find_button, NULL);
 	}
@@ -1111,6 +1172,7 @@ handle_search_command_stdout_io (GIOChannel 	*ioc,
 				 gpointer 	data) 
 {
 	struct _SearchStruct *search_data = data;
+	gboolean             broken_pipe = FALSE;
 
 	if ((condition == G_IO_IN) || (condition == G_IO_IN + G_IO_HUP)) { 
 	
@@ -1130,13 +1192,21 @@ handle_search_command_stdout_io (GIOChannel 	*ioc,
 			gchar *utf8 = NULL;
 			gchar *filename = NULL;
 			
-			if (search_data->running != RUNNING) {
+			if (search_data->running == MAKE_IT_STOP) {
+				broken_pipe = TRUE;
+				break;
+			} 
+			else if (search_data->running != RUNNING) {
 			 	break;
 			}
 			
 			do {
 				status = g_io_channel_read_line_string (ioc, string, NULL, &error);
 				
+				if (status == G_IO_STATUS_EOF) {
+					broken_pipe = TRUE;
+				}
+				
 				while (gtk_events_pending ()) {
 					if (search_data->running == MAKE_IT_QUIT) {
 						return FALSE;
@@ -1144,7 +1214,11 @@ handle_search_command_stdout_io (GIOChannel 	*ioc,
 					gtk_main_iteration (); 				
 				}
 				
-			} while (status == G_IO_STATUS_AGAIN);
+			} while (status == G_IO_STATUS_AGAIN && broken_pipe == FALSE);
+			
+			if (broken_pipe == TRUE) {
+				break;
+			}
 			
 			if (status != G_IO_STATUS_NORMAL) {
 				if (error != NULL) {
@@ -1171,11 +1245,11 @@ handle_search_command_stdout_io (GIOChannel 	*ioc,
 					filename = g_path_get_basename (utf8);
 			
 					if (fnmatch (search_data->file_is_named_pattern, filename, FNM_NOESCAPE | FNM_CASEFOLD ) != FNM_NOMATCH) {
-						if (search_data->show_hidden_files == TRUE) {
+						if (search_data->show_hidden_files) {
 							if (search_data->regex_matching_enabled == FALSE) {
 								add_file_to_search_results (string->str, interface.model, &interface.iter);
 							} 
-							else if (compare_regex (search_data->regex_string, filename) == TRUE) {
+							else if (compare_regex (search_data->regex_string, filename)) {
 								add_file_to_search_results (string->str, interface.model, &interface.iter);
 							}
 						}
@@ -1183,7 +1257,7 @@ handle_search_command_stdout_io (GIOChannel 	*ioc,
 							if (search_data->regex_matching_enabled == FALSE) {
 								add_file_to_search_results (string->str, interface.model, &interface.iter);
 							} 
-							else if (compare_regex (search_data->regex_string, filename) == TRUE) {
+							else if (compare_regex (search_data->regex_string, filename)) {
 								add_file_to_search_results (string->str, interface.model, &interface.iter);
 							}
 						}
@@ -1214,43 +1288,18 @@ handle_search_command_stdout_io (GIOChannel 	*ioc,
 		g_string_free (string, TRUE);
 	}
 
-	if (condition != G_IO_IN) { 
-	
-		gint   total_files;
-		gchar *status_bar_string = NULL;
-		gchar *search_status = g_strdup ("");
+	if (condition != G_IO_IN || broken_pipe == TRUE) { 
 		
 		if (search_data->running == MAKE_IT_STOP) {
-			search_status = g_strdup (_("(stopped)"));
+			search_data->aborted = TRUE;
 		}
 		
 		search_data->lock = FALSE;
 		search_data->running = NOT_RUNNING;
-		
 		search_data->not_running_timeout = TRUE;
 		g_timeout_add (500, not_running_timeout_cb, NULL);
 
-		total_files = gtk_tree_model_iter_n_children (GTK_TREE_MODEL(interface.model), NULL);
-
-		if (total_files == 0) {
-			status_bar_string = g_strdup (_("No files found"));
-			add_no_files_found_message (interface.model, &interface.iter);
-		}
-		else if (total_files == 1) {
-			status_bar_string = g_strdup (_("One file found"));
-		}
-		else {
-			status_bar_string = g_strdup_printf (_("%d files found"), total_files);
-		}
-		
-		if (strlen(search_status) > 0) {
-			status_bar_string = g_strconcat (status_bar_string, " ", search_status, NULL);
-		}
-		gtk_label_set_text (GTK_LABEL (interface.results_label), status_bar_string);
-		
-		status_bar_string = g_strconcat (status_bar_string, " - ", _("Search for Files"), NULL);
-		gtk_window_set_title (GTK_WINDOW (interface.main_window), status_bar_string);
-
+		update_search_counts ();
 		stop_animation ();
 
 		gtk_window_set_default (GTK_WINDOW(interface.main_window), interface.find_button);
@@ -1262,8 +1311,6 @@ handle_search_command_stdout_io (GIOChannel 	*ioc,
 		gtk_widget_show (interface.find_button);
 
 		g_io_channel_shutdown (ioc, TRUE, NULL);
-		g_free (status_bar_string);
-		
 		return FALSE;
 	}
 	return TRUE;
@@ -1277,6 +1324,7 @@ handle_search_command_stderr_io (GIOChannel 	*ioc,
 	struct _SearchStruct *search_data = data;
 	static GString       *error_msgs = NULL;
 	static gboolean      truncate_error_msgs = FALSE;
+	gboolean             broken_pipe = FALSE;
 	
 	if ((condition == G_IO_IN) || (condition == G_IO_IN + G_IO_HUP)) { 
 	
@@ -1298,6 +1346,10 @@ handle_search_command_stderr_io (GIOChannel 	*ioc,
 			do {
 				status = g_io_channel_read_line_string (ioc, string, NULL, &error);
 	
+				if (status == G_IO_STATUS_EOF) {
+					broken_pipe = TRUE;
+				}
+	
 				while (gtk_events_pending ()) {
 					if (search_data->running == MAKE_IT_QUIT) {
 						break;
@@ -1305,7 +1357,11 @@ handle_search_command_stderr_io (GIOChannel 	*ioc,
 					gtk_main_iteration ();
 				}
 					
-			} while (status == G_IO_STATUS_AGAIN);
+			} while (status == G_IO_STATUS_AGAIN && broken_pipe == FALSE);
+			
+			if (broken_pipe == TRUE) {
+				break;
+			}
 			
 			if (status != G_IO_STATUS_NORMAL) {
 				if (error != NULL) {
@@ -1332,7 +1388,7 @@ handle_search_command_stderr_io (GIOChannel 	*ioc,
 		g_free (utf8);
 	}
 	
-	if (condition != G_IO_IN) { 
+	if (condition != G_IO_IN || broken_pipe == TRUE) { 
 	
 		if (error_msgs != NULL) {
 
@@ -1343,7 +1399,7 @@ handle_search_command_stderr_io (GIOChannel 	*ioc,
 				error_msgs = g_string_prepend (error_msgs, 
 				     _("While searching the following errors were reported.\n\n"));
 				
-				if (truncate_error_msgs == TRUE) {
+				if (truncate_error_msgs) {
 					error_msgs = g_string_append (error_msgs, 
 				     		_("\n... Too many errors to display ..."));
 				}
@@ -1396,6 +1452,7 @@ spawn_search_command (gchar *command)
 		gtk_dialog_run (GTK_DIALOG (dialog));
 		gtk_widget_destroy (dialog);
 		g_error_free (error);
+		g_strfreev (argv);
 		return;
 	}	
 
@@ -1420,6 +1477,7 @@ spawn_search_command (gchar *command)
 	}
 	
 	search_command.lock = TRUE;
+	search_command.aborted = FALSE;
 	search_command.running = RUNNING; 
 
 	gtk_window_set_default (GTK_WINDOW(interface.main_window), interface.stop_button);
@@ -1476,7 +1534,8 @@ create_constraint_box (SearchConstraint *opt, gchar *value)
 		break;
 	case SEARCH_CONSTRAINT_TEXT:
 	case SEARCH_CONSTRAINT_NUMBER:
-	case SEARCH_CONSTRAINT_TIME:
+	case SEARCH_CONSTRAINT_TIME_LESS:
+	case SEARCH_CONSTRAINT_TIME_MORE:
 		{
 			gchar *desc = g_strconcat (LEFT_LABEL_SPACING, _(templates[opt->constraint_id].desc), ":", NULL);
 			label = gtk_label_new_with_mnemonic (desc);
@@ -1555,7 +1614,7 @@ add_constraint (gint constraint_id, gchar *value, gboolean show_constraint)
 	SearchConstraint *constraint = g_new(SearchConstraint,1);
 	GtkWidget *widget;
 
-	if (show_constraint == TRUE) {
+	if (show_constraint) {
 		if (GTK_WIDGET_VISIBLE (interface.additional_constraints) == FALSE) {
 			g_signal_emit_by_name (G_OBJECT(interface.checkbutton), "clicked", 0);
 			gtk_widget_show (interface.additional_constraints);
@@ -1564,7 +1623,7 @@ add_constraint (gint constraint_id, gchar *value, gboolean show_constraint)
 	
 	interface.geometry.min_height += 35;
 	
-	if (GTK_WIDGET_VISIBLE (interface.additional_constraints) == TRUE) {
+	if (GTK_WIDGET_VISIBLE (interface.additional_constraints)) {
 		gtk_window_set_geometry_hints (GTK_WINDOW (interface.main_window), 
 		                               GTK_WIDGET (interface.main_window),
 		                               &interface.geometry, 
@@ -1682,9 +1741,9 @@ create_search_results_section (void)
 				     GTK_SELECTION_MULTIPLE);
 				     
 	gtk_drag_source_set (interface.tree, 
-			     GDK_BUTTON1_MASK,
+			     GDK_BUTTON1_MASK | GDK_BUTTON2_MASK,
 			     dnd_table, n_dnds, 
-			     GDK_ACTION_COPY | GDK_ACTION_MOVE);	
+			     GDK_ACTION_COPY | GDK_ACTION_MOVE | GDK_ACTION_ASK);	
 
 	g_signal_connect (G_OBJECT (interface.tree), 
 			  "drag_data_get",
@@ -2002,6 +2061,7 @@ set_clone_command (gint *argcp, gchar ***argvp, gpointer client_data, gboolean e
 	gchar *file_is_named_locale;
 	gchar *look_in_folder_utf8;
 	gchar *look_in_folder_locale;
+	gchar *tmp;
 	GList *list;
 	gint  i = 0;
 
@@ -2012,20 +2072,28 @@ set_clone_command (gint *argcp, gchar ***argvp, gpointer client_data, gboolean e
 	file_is_named_utf8 = (gchar *) gtk_entry_get_text (GTK_ENTRY(gnome_entry_gtk_entry (GNOME_ENTRY(interface.file_is_named_entry))));
 	file_is_named_locale = g_locale_from_utf8 (file_is_named_utf8 != NULL ? file_is_named_utf8 : "" , 
 	                                           -1, NULL, NULL, NULL);
-	argv[i++] = (escape_values == TRUE) ? 
-	            g_strdup_printf ("--named=\"%s\"", g_strescape (file_is_named_locale, NULL)) : 
-		    g_strdup_printf ("--named=%s", file_is_named_locale);	
+	if (escape_values)
+		tmp = g_shell_quote (file_is_named_locale);
+	else
+		tmp = g_strdup (file_is_named_locale);
+	argv[i++] = g_strdup_printf ("--named=%s", tmp);	
+	g_free (tmp);
 	g_free (file_is_named_locale);
 
 	look_in_folder_utf8 = gnome_file_entry_get_full_path (GNOME_FILE_ENTRY(interface.look_in_folder_entry), FALSE);
 	look_in_folder_locale = g_locale_from_utf8 (look_in_folder_utf8 != NULL ? look_in_folder_utf8 : "", 
 	                                            -1, NULL, NULL, NULL);
-	argv[i++] = (escape_values == TRUE) ? 
-	            g_strdup_printf ("--path=\"%s\"", g_strescape (look_in_folder_locale, NULL)) : 
-		    g_strdup_printf ("--path=%s", look_in_folder_locale);
+	g_free (look_in_folder_utf8);
+	
+	if (escape_values)
+		tmp = g_shell_quote (look_in_folder_locale);
+	else
+		tmp = g_strdup (look_in_folder_locale);
+	argv[i++] = g_strdup_printf ("--path=%s", tmp);
+	g_free (tmp);
 	g_free (look_in_folder_locale);
 
-	if (GTK_WIDGET_VISIBLE(interface.additional_constraints) == TRUE) {
+	if (GTK_WIDGET_VISIBLE(interface.additional_constraints)) {
 		for (list = interface.selected_constraints; list != NULL; list = g_list_next (list)) {
 			SearchConstraint *constraint = list->data;
 			gchar *locale = NULL;
@@ -2033,9 +2101,12 @@ set_clone_command (gint *argcp, gchar ***argvp, gpointer client_data, gboolean e
 			switch (constraint->constraint_id) {
 			case SEARCH_CONSTRAINT_CONTAINS_THE_TEXT:
 				locale = g_locale_from_utf8 (constraint->data.text, -1, NULL, NULL, NULL);
-				argv[i++] = (escape_values == TRUE) ? 
-				            g_strdup_printf ("--contains=\"%s\"", g_strescape (locale, NULL)) : 
-					    g_strdup_printf ("--contains=%s", locale);
+				if (escape_values)
+					tmp = g_shell_quote (locale);
+				else
+					tmp = g_strdup (locale);
+				argv[i++] = g_strdup_printf ("--contains=%s", tmp);
+				g_free (tmp);
 				break;
 			case SEARCH_CONSTRAINT_DATE_MODIFIED_BEFORE:
 				argv[i++] = g_strdup_printf ("--mtimeless=%d", constraint->data.time);
@@ -2054,30 +2125,42 @@ set_clone_command (gint *argcp, gchar ***argvp, gpointer client_data, gboolean e
 				break;
 			case SEARCH_CONSTRAINT_OWNED_BY_USER:
 				locale = g_locale_from_utf8 (constraint->data.text, -1, NULL, NULL, NULL);
-				argv[i++] = (escape_values == TRUE) ? 
-				            g_strdup_printf ("--user=\"%s\"", g_strescape (locale, NULL)) : 
-					    g_strdup_printf ("--user=%s", locale);
+				if (escape_values)
+					tmp = g_shell_quote (locale);
+				else
+					tmp = g_strdup (locale);
+				argv[i++] = g_strdup_printf ("--user=%s", tmp);
+				g_free (tmp);
 				break;
 			case SEARCH_CONSTRAINT_OWNED_BY_GROUP:
 				locale = g_locale_from_utf8 (constraint->data.text, -1, NULL, NULL, NULL);
-				argv[i++] = (escape_values == TRUE) ? 
-				            g_strdup_printf ("--group=\"%s\"", g_strescape (locale, NULL)) : 
-					    g_strdup_printf ("--group=%s", locale);
+				if (escape_values)
+					tmp = g_shell_quote (locale);
+				else
+					tmp = g_strdup (locale);
+				argv[i++] = g_strdup_printf ("--group=%s", tmp);
+				g_free (tmp);
 				break;
 			case SEARCH_CONSTRAINT_OWNER_IS_UNRECOGNIZED:
 				argv[i++] = g_strdup ("--nouser");
 				break;
 			case SEARCH_CONSTRAINT_FILE_IS_NOT_NAMED:
 				locale = g_locale_from_utf8 (constraint->data.text, -1, NULL, NULL, NULL);
-				argv[i++] = (escape_values == TRUE) ? 
-				            g_strdup_printf ("--notnamed=\"%s\"", g_strescape (locale, NULL)) : 
-					    g_strdup_printf ("--notnamed=%s", locale);
+				if (escape_values)
+					tmp = g_shell_quote (locale);
+				else
+					tmp = g_strdup (locale);
+				argv[i++] = g_strdup_printf ("--notnamed=%s", tmp);
+				g_free (tmp);
 				break;
 			case SEARCH_CONSTRAINT_FILE_MATCHES_REGULAR_EXPRESSION:
 				locale = g_locale_from_utf8 (constraint->data.text, -1, NULL, NULL, NULL);
-				argv[i++] = (escape_values == TRUE) ? 
-				            g_strdup_printf ("--regex=\"%s\"", g_strescape (locale, NULL)) : 
-					    g_strdup_printf ("--regex=%s", locale);
+				if (escape_values)
+					tmp = g_shell_quote (locale);
+				else
+					tmp = g_strdup (locale);
+				argv[i++] = g_strdup_printf ("--regex=%s", tmp);
+				g_free (tmp);
 				break;
 			case SEARCH_CONSTRAINT_SHOW_HIDDEN_FILES_AND_FOLDERS:
 				argv[i++] = g_strdup ("--hidden");
@@ -2091,7 +2174,7 @@ set_clone_command (gint *argcp, gchar ***argvp, gpointer client_data, gboolean e
 			default:
 				break;
 			}
-		g_free (locale);
+			g_free (locale);
 		}		
 	}
 	*argvp = argv;
@@ -2101,66 +2184,66 @@ set_clone_command (gint *argcp, gchar ***argvp, gpointer client_data, gboolean e
 void
 handle_gconf_settings (void)
 {
-	if (gsearchtool_gconf_get_boolean ("/apps/gnome-search-tool/show_additional_options") == TRUE) {
+	if (gsearchtool_gconf_get_boolean ("/apps/gnome-search-tool/show_additional_options")) {
 		if (GTK_WIDGET_VISIBLE (interface.additional_constraints) == FALSE) {
 			g_signal_emit_by_name (G_OBJECT(interface.checkbutton), "clicked", 0);
 			gtk_widget_show (interface.additional_constraints);
 		}
 	}
 		      
-	if (gsearchtool_gconf_get_boolean ("/apps/gnome-search-tool/contains_the_text") == TRUE) {
+	if (gsearchtool_gconf_get_boolean ("/apps/gnome-search-tool/select/contains_the_text")) {
 		add_constraint (SEARCH_CONSTRAINT_CONTAINS_THE_TEXT, "", FALSE); 
 	}
 		
-	if (gsearchtool_gconf_get_boolean ("/apps/gnome-search-tool/date_modified_less_than") == TRUE) {
+	if (gsearchtool_gconf_get_boolean ("/apps/gnome-search-tool/select/date_modified_less_than")) {
 		add_constraint (SEARCH_CONSTRAINT_DATE_MODIFIED_BEFORE, "", FALSE); 
 	}
 	
-	if (gsearchtool_gconf_get_boolean ("/apps/gnome-search-tool/date_modified_more_than") == TRUE) {
+	if (gsearchtool_gconf_get_boolean ("/apps/gnome-search-tool/select/date_modified_more_than")) {
 		add_constraint (SEARCH_CONSTRAINT_DATE_MODIFIED_AFTER, "", FALSE); 
 	}
 	
-	if (gsearchtool_gconf_get_boolean ("/apps/gnome-search-tool/size_at_least") == TRUE) {
+	if (gsearchtool_gconf_get_boolean ("/apps/gnome-search-tool/select/size_at_least")) {
 		add_constraint (SEARCH_CONSTRAINT_SIZE_IS_MORE_THAN, "", FALSE); 
 	}
 	
-	if (gsearchtool_gconf_get_boolean ("/apps/gnome-search-tool/size_at_most") == TRUE) {
+	if (gsearchtool_gconf_get_boolean ("/apps/gnome-search-tool/select/size_at_most")) {
 		add_constraint (SEARCH_CONSTRAINT_SIZE_IS_LESS_THAN, "", FALSE); 
 	}
 	
-	if (gsearchtool_gconf_get_boolean ("/apps/gnome-search-tool/file_is_empty") == TRUE) {
+	if (gsearchtool_gconf_get_boolean ("/apps/gnome-search-tool/select/file_is_empty")) {
 		add_constraint (SEARCH_CONSTRAINT_FILE_IS_EMPTY, NULL, FALSE); 
 	}
 	
-	if (gsearchtool_gconf_get_boolean ("/apps/gnome-search-tool/owned_by_user") == TRUE) {
+	if (gsearchtool_gconf_get_boolean ("/apps/gnome-search-tool/select/owned_by_user")) {
 		add_constraint (SEARCH_CONSTRAINT_OWNED_BY_USER, "", FALSE); 
 	}
 	
-	if (gsearchtool_gconf_get_boolean ("/apps/gnome-search-tool/owned_by_group") == TRUE) {
+	if (gsearchtool_gconf_get_boolean ("/apps/gnome-search-tool/select/owned_by_group")) {
 		add_constraint (SEARCH_CONSTRAINT_OWNED_BY_GROUP, "", FALSE); 
 	}
 	
-	if (gsearchtool_gconf_get_boolean ("/apps/gnome-search-tool/owner_is_unrecognized") == TRUE) {
+	if (gsearchtool_gconf_get_boolean ("/apps/gnome-search-tool/select/owner_is_unrecognized")) {
 		add_constraint (SEARCH_CONSTRAINT_OWNER_IS_UNRECOGNIZED, NULL, FALSE); 
 	}
 	
-	if (gsearchtool_gconf_get_boolean ("/apps/gnome-search-tool/name_does_not_contain") == TRUE) {
+	if (gsearchtool_gconf_get_boolean ("/apps/gnome-search-tool/select/name_does_not_contain")) {
 		add_constraint (SEARCH_CONSTRAINT_FILE_IS_NOT_NAMED, "", FALSE); 
 	}
 	
-	if (gsearchtool_gconf_get_boolean ("/apps/gnome-search-tool/name_matches_regular_expression") == TRUE) {
+	if (gsearchtool_gconf_get_boolean ("/apps/gnome-search-tool/select/name_matches_regular_expression")) {
 		add_constraint (SEARCH_CONSTRAINT_FILE_MATCHES_REGULAR_EXPRESSION, "", FALSE); 
 	}
 	
-	if (gsearchtool_gconf_get_boolean ("/apps/gnome-search-tool/show_hidden_files_and_folders") == TRUE) {
+	if (gsearchtool_gconf_get_boolean ("/apps/gnome-search-tool/select/show_hidden_files_and_folders")) {
 		add_constraint (SEARCH_CONSTRAINT_SHOW_HIDDEN_FILES_AND_FOLDERS, NULL, FALSE); 
 	}
 	
-	if (gsearchtool_gconf_get_boolean ("/apps/gnome-search-tool/follow_symbolic_links") == TRUE) {
+	if (gsearchtool_gconf_get_boolean ("/apps/gnome-search-tool/select/follow_symbolic_links")) {
 		add_constraint (SEARCH_CONSTRAINT_FOLLOW_SYMBOLIC_LINKS, NULL, FALSE); 
 	}
 	
-	if (gsearchtool_gconf_get_boolean ("/apps/gnome-search-tool/include_other_filesystems") == TRUE) {
+	if (gsearchtool_gconf_get_boolean ("/apps/gnome-search-tool/select/include_other_filesystems")) {
 		add_constraint (SEARCH_CONSTRAINT_SEARCH_OTHER_FILESYSTEMS, NULL, FALSE); 
 	}
 }
@@ -2173,6 +2256,8 @@ main (int 	argc,
 	GnomeClient  *client;
 	GtkWidget    *window;
 
+	memset (&interface, 0, sizeof (interface));
+
 	global_gconf_client = NULL;
 	interface.geometry.min_height = MINIMUM_WINDOW_HEIGHT;
 	interface.geometry.min_width  = MINIMUM_WINDOW_WIDTH;
