@@ -28,12 +28,6 @@
 #ifndef _GSEARCHTOOL_H_
 #define _GSEARCHTOOL_H_
 
-#define GDK_DISABLE_DEPRECATED
-#define GDK_PIXBUF_DISABLE_DEPRECATED
-#define G_DISABLE_DEPRECATED
-#define GTK_DISABLE_DEPRECATED
-#define GNOME_DISABLE_DEPRECATED
-
 #define MINIMUM_WINDOW_WIDTH   422
 #define MINIMUM_WINDOW_HEIGHT  310
 #define GNOME_SEARCH_TOOL_ICON  "gnome-searchtool.png"
@@ -53,7 +47,8 @@ typedef enum {
 	SEARCH_CONSTRAINT_BOOL, 
 	SEARCH_CONSTRAINT_TEXT,
 	SEARCH_CONSTRAINT_NUMBER,
-	SEARCH_CONSTRAINT_TIME,
+	SEARCH_CONSTRAINT_TIME_LESS,
+	SEARCH_CONSTRAINT_TIME_MORE,
 	SEARCH_CONSTRAINT_SEPARATOR
 } SearchConstraintType;
 
@@ -88,6 +83,7 @@ struct _SearchStruct {
 	gboolean		show_hidden_files;
 	gboolean		regex_matching_enabled;
 	gboolean		not_running_timeout;
+	gboolean		aborted;
 	RunStatus        	running;
 } search_command;
 
@@ -170,6 +166,9 @@ set_clone_command		(gint *argcp,
 gchar *
 get_desktop_item_name 		(void);
 
+void
+update_search_counts 		(void);
+
 #ifdef __cplusplus
 }
 #endif
